@@ -21,7 +21,7 @@
 #ifndef KPTNODE_H
 #define KPTNODE_H
 
-#include "kplatokernel_export.h"
+#include "plankernel_export.h"
 
 #include "kptglobal.h"
 #include "kptrelation.h"
@@ -55,13 +55,14 @@ class EffortCostMap;
 class EffortCost;
 class Calendar;
 class KPlatoXmlLoaderBase;
+class XmlSaveContext;
 
 /**
  * This class represents any node in the project, a node can be a project or
  * a subproject or any task.
  * This class is basically an abstract interface to make the design more OO.
  */
-class KPLATOKERNEL_EXPORT Node : public QObject
+class PLANKERNEL_EXPORT Node : public QObject
 {
     Q_OBJECT
 public:
@@ -78,33 +79,51 @@ public:
         State_Running = 64,
         State_RunningLate = 128,
         State_RunningEarly = 256,
-        State_ReadyToStart = 512, // all precceeding tasks finished (if any)
-        State_NotReadyToStart = 1024, // all precceeding tasks not finished (must be one or more)
+        State_ReadyToStart = 512, // all preceding tasks finished (if any)
+        State_NotReadyToStart = 1024, // all preceding tasks not finished (must be one or more)
         State_NotScheduled = 2048,
         State_Late = 4096
     };
+    Q_ENUM(State);
 
     enum Properties {
-        Type,
-        StartupCost,
-        ShutdownCost,
-        CompletionEntry,
-        CompletionStarted,
-        CompletionFinished,
-        CompletionStartTime,
-        CompletionFinishTime,
-        CompletionPercentage,
-        CompletionRemainingEffort,
-        CompletionActualEffort,
-        CompletionUsedEffort
+        NameProperty,
+        LeaderProperty,
+        DescriptionProperty,
+        TypeProperty,
+        RunningAccountProperty,
+        StartupCostProperty,
+        StartupAccountProperty,
+        ShutdownCostProperty,
+        ShutdownAccountProperty,
+        CompletionEntryProperty,
+        CompletionStartedProperty,
+        CompletionFinishedProperty,
+        CompletionStartTimeProperty,
+        CompletionFinishTimeProperty,
+        CompletionPercentageProperty,
+        CompletionRemainingEffortProperty,
+        CompletionActualEffortProperty,
+        CompletionUsedEffortProperty,
+        CompletionNoteProperty,
+        ResourceRequestProperty,
+        ConstraintTypeProperty,
+        StartConstraintProperty,
+        EndConstraintProperty,
+        PriorityProperty,
+        EstimateProperty,
+        EstimateRiskProperty,
+        EstimateOptimisticProperty,
+        EstimatePessimisticProperty
     };
+    Q_ENUM(Properties);
 
     explicit Node(Node *parent = 0);
     Node(const Node &node, Node *parent = 0);
 
 
     // Declare the class abstract
-    virtual ~Node() = 0;
+    ~Node() override = 0;
 
     void setId(const QString& id);
     QString id() const { return m_id; } // unique identity
@@ -121,9 +140,9 @@ public:
 
     virtual int type() const = 0;
     
-    QString typeToString( bool trans = false ) const;
-    static QString typeToString( NodeTypes typ, bool trans = false );
-    static QStringList typeToStringList( bool trans );
+    QString typeToString(bool trans = false) const;
+    static QString typeToString(NodeTypes typ, bool trans = false);
+    static QStringList typeToStringList(bool trans);
     /**
      * Returns a pointer to the project node (main- or sub-project)
      * Returns 0 if no project exists.
@@ -137,30 +156,30 @@ public:
     
     // The load and save methods
     virtual bool load(KoXmlElement &, XMLLoaderObject &) { return true; }
-    virtual void save(QDomElement &element) const  = 0;
+    virtual void save(QDomElement &element, const XmlSaveContext &context) const  = 0;
     /// Save me and my childrens relations.
-    virtual void saveRelations(QDomElement &element) const;
+    virtual void saveRelations(QDomElement &element, const XmlSaveContext &context) const;
 
     /// Save a workpackage document containing @p node with schedule identity @p id
-    virtual void saveWorkPackageXML( QDomElement &element, long id ) const;
+    virtual void saveWorkPackageXML(QDomElement &element, long id) const;
 
     // simple child node management
     // Child nodes are things like subtasks, basically a task can exists of
     // several sub-tasks. Creating a table has 4 subtasks, 1) measuring
     // 2) cutting 3) building 4) painting.
     Node *parentNode() const { return m_parent; }
-    void setParentNode( Node* newParent ) { m_parent = newParent;}
+    void setParentNode(Node* newParent) { m_parent = newParent;}
     const QList<Node*> &childNodeIterator() const { return m_nodes; }
     int numChildren() const { return m_nodes.count(); }
     virtual void addChildNode(Node *node, Node *after=0);
     virtual void insertChildNode(int index, Node *node);
-    void takeChildNode(Node *node );
-    void takeChildNode(int number );
+    void takeChildNode(Node *node);
+    void takeChildNode(int number);
     Node* childNode(int number);
     const Node* childNode(int number) const;
-    int findChildNode( const Node* node ) const;
-    bool isChildOf( const Node *node ) const;
-    int indexOf( const Node *node ) const;
+    int findChildNode(const Node* node) const;
+    bool isChildOf(const Node *node) const;
+    int indexOf(const Node *node) const;
 
     // Time-dependent child-node-management.
     // list all nodes that are dependent upon this one.
@@ -170,18 +189,18 @@ public:
 
     int numDependChildNodes() const { return m_dependChildNodes.count(); }
     /// Adds relation of type @p p to both this node and @p node
-    virtual void addDependChildNode( Node *node, Relation::Type p=Relation::FinishStart);
+    virtual void addDependChildNode(Node *node, Relation::Type p=Relation::FinishStart);
     /// Adds relation of type @p p with @p lag to both this node and @p node
-    virtual void addDependChildNode( Node *node, Relation::Type p, Duration lag);
+    virtual void addDependChildNode(Node *node, Relation::Type p, Duration lag);
     /// Adds @p relation only to this node
-    virtual bool addDependChildNode( Relation *relation);
+    virtual bool addDependChildNode(Relation *relation);
     /// Inserts relation to this node at index @p index and appends relation to @p node
-    virtual void insertDependChildNode( unsigned int index, Node *node, Relation::Type p=Relation::FinishStart);
+    virtual void insertDependChildNode(unsigned int index, Node *node, Relation::Type p=Relation::FinishStart);
     /**
      * Takes the relation rel from this node only.
      */
-    void takeDependChildNode( Relation *rel );
-    Relation *getDependChildNode( int number ) const {
+    void takeDependChildNode(Relation *rel);
+    Relation *getDependChildNode(int number) const {
         return m_dependChildNodes.at(number);
     }
     QList<Relation*> dependChildNodes() const { return m_dependChildNodes; }
@@ -190,41 +209,41 @@ public:
     /// Adds relation if type @p to both this node and @p node
     virtual void addDependParentNode(Node *node, Relation::Type p=Relation::FinishStart);
     /// Adds relation to both this node and @p node
-    virtual void addDependParentNode( Node *node, Relation::Type p, Duration lag);
+    virtual void addDependParentNode(Node *node, Relation::Type p, Duration lag);
     /// Adds relation only to this node
-    virtual bool addDependParentNode( Relation *relation);
+    virtual bool addDependParentNode(Relation *relation);
     /// Inserts relation to this node at index and appends relation to @p node
-    virtual void insertDependParentNode( unsigned int index, Node *node, Relation::Type p=Relation::FinishStart);
+    virtual void insertDependParentNode(unsigned int index, Node *node, Relation::Type p=Relation::FinishStart);
     /**
      * Takes the relation @p rel from this node only.
      */
-    void takeDependParentNode( Relation *rel );
-    Relation *getDependParentNode( int number ) const {
+    void takeDependParentNode(Relation *rel);
+    Relation *getDependParentNode(int number) const {
         return m_dependParentNodes.at(number);
     }
     QList<Relation*> dependParentNodes() const { return m_dependParentNodes; }
     QList<Node*> getParentNodes();
-    bool isParentOf( const Node *node ) const;
-    bool isDependChildOf( const Node *node ) const;
-    virtual bool canMoveTo( const Node *newParent ) const;
+    bool isParentOf(const Node *node) const;
+    bool isDependChildOf(const Node *node) const;
+    virtual bool canMoveTo(const Node *newParent) const;
     
-    Relation *findParentRelation( const Node *node) const;
-    Relation *findChildRelation( const Node *node ) const;
-    Relation *findRelation( const Node *node ) const;
+    Relation *findParentRelation(const Node *node) const;
+    Relation *findChildRelation(const Node *node) const;
+    Relation *findRelation(const Node *node) const;
 
     /// Set the scheduled start time
-    void setStartTime(const DateTime &startTime, long id = CURRENTSCHEDULE );
+    void setStartTime(const DateTime &startTime, long id = CURRENTSCHEDULE);
     /// Return the scheduled start time
-    virtual DateTime startTime( long id = CURRENTSCHEDULE ) const;
+    virtual DateTime startTime(long id = CURRENTSCHEDULE) const;
     /// Set the scheduled end time
-    void setEndTime(const DateTime &endTime, long id = CURRENTSCHEDULE );
+    void setEndTime(const DateTime &endTime, long id = CURRENTSCHEDULE);
     /// Return the scheduled end time
-    virtual DateTime endTime( long id = CURRENTSCHEDULE ) const;
+    virtual DateTime endTime(long id = CURRENTSCHEDULE) const;
     /// Set the scheduled duration
-    void setDuration(const Duration &duration, long id = CURRENTSCHEDULE );
+    void setDuration(const Duration &duration, long id = CURRENTSCHEDULE);
 
-    DateTime appointmentStartTime( long id = CURRENTSCHEDULE) const;
-    DateTime appointmentEndTime( long id = CURRENTSCHEDULE ) const;
+    DateTime appointmentStartTime(long id = CURRENTSCHEDULE) const;
+    DateTime appointmentEndTime(long id = CURRENTSCHEDULE) const;
 
     /// Return the estimate for this node
     Estimate *estimate() const { return m_estimate; }
@@ -255,13 +274,13 @@ public:
     void setConstraint(Node::ConstraintType type);
     void setConstraint(const QString &type);
     int constraint() const { return m_constraint; }
-    QString constraintToString( bool trans=false ) const;
-    static QStringList constraintList( bool trans );
+    QString constraintToString(bool trans=false) const;
+    static QStringList constraintList(bool trans);
     
     virtual void setConstraintStartTime(const DateTime &time)
-        { m_constraintStartTime = time; changed( this ); }
+        { m_constraintStartTime = time; changed(this, StartConstraintProperty); }
     virtual void setConstraintEndTime(const DateTime &time)
-        { m_constraintEndTime = time; changed( this ); }
+        { m_constraintEndTime = time; changed(this, EndConstraintProperty); }
 
     virtual DateTime constraintStartTime() const { return m_constraintStartTime; }
     virtual DateTime constraintEndTime() const { return m_constraintEndTime; }
@@ -272,11 +291,11 @@ public:
 
     virtual ResourceGroupRequest *resourceGroupRequest(const ResourceGroup * /*group*/) const { return 0; }
     virtual QStringList requestNameList() const { return QStringList(); }
-    virtual bool containsRequest( const QString &/*identity*/ ) const { return false; }
-    virtual ResourceRequest *resourceRequest( const QString &/*name*/ ) const { return 0; }
+    virtual bool containsRequest(const QString &/*identity*/) const { return false; }
+    virtual ResourceRequest *resourceRequest(const QString &/*name*/) const { return 0; }
     
     /// Return the list of resources assigned to this task
-    virtual QStringList assignedNameList( long /*id*/ = CURRENTSCHEDULE ) const { return QStringList(); }
+    virtual QStringList assignedNameList(long /*id*/ = CURRENTSCHEDULE) const { return QStringList(); }
     
     virtual void makeAppointments();
     /// Calculates if the assigned resource is overbooked 
@@ -284,98 +303,98 @@ public:
     virtual void calcResourceOverbooked();
 
     /// Return the scheduling status of schedule @p id. If @p trans is true, text is translated
-    QStringList schedulingStatus( long id, bool trans = false ) const;
+    QStringList schedulingStatus(long id, bool trans = false) const;
     /// EstimateType == Estimate, but no resource is requested
-    bool resourceError( long id = CURRENTSCHEDULE ) const;
+    bool resourceError(long id = CURRENTSCHEDULE) const;
     /// The assigned resource is overbooked
-    virtual bool resourceOverbooked( long id = CURRENTSCHEDULE ) const;
+    virtual bool resourceOverbooked(long id = CURRENTSCHEDULE) const;
     /// The requested resource is not available
-    bool resourceNotAvailable( long id = CURRENTSCHEDULE ) const;
-    /// The task cannot be scheduled to fullfil all the constraints
-    virtual bool constraintError( long id = CURRENTSCHEDULE ) const;
+    bool resourceNotAvailable(long id = CURRENTSCHEDULE) const;
+    /// The task cannot be scheduled to fulfill all the constraints
+    virtual bool constraintError(long id = CURRENTSCHEDULE) const;
     /// The task cannot be scheduled correctly
-    virtual bool schedulingError( long id = CURRENTSCHEDULE ) const;
+    virtual bool schedulingError(long id = CURRENTSCHEDULE) const;
     /// The node has not been scheduled
-    bool notScheduled( long id = CURRENTSCHEDULE ) const;
+    bool notScheduled(long id = CURRENTSCHEDULE) const;
     /// Return a list of overbooked resources
-    virtual QStringList overbookedResources( long id = CURRENTSCHEDULE ) const;
-    /// The assigned resources can not fullfil the estimated effort.
-    virtual bool effortMetError( long /*id*/ = CURRENTSCHEDULE ) const { return false; }
+    virtual QStringList overbookedResources(long id = CURRENTSCHEDULE) const;
+    /// The assigned resources can not fulfill the estimated effort.
+    virtual bool effortMetError(long /*id*/ = CURRENTSCHEDULE) const { return false; }
     
-    virtual EffortCostMap plannedEffortCostPrDay(QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const=0;
-    virtual EffortCostMap plannedEffortCostPrDay(const Resource *resource, QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const=0;
+    virtual EffortCostMap plannedEffortCostPrDay(QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const=0;
+    virtual EffortCostMap plannedEffortCostPrDay(const Resource *resource, QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const=0;
 
     /// Returns the total planned effort for @p resource on this task (or subtasks)
-    virtual Duration plannedEffort( const Resource *resource, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
+    virtual Duration plannedEffort(const Resource *resource, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const;
     /// Returns the total planned effort for this task (or subtasks) 
-    virtual Duration plannedEffort( long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return Duration::zeroDuration; }
+    virtual Duration plannedEffort(long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const { Q_UNUSED(id); return Duration::zeroDuration; }
     /// Returns the total planned effort for this task (or subtasks) on date
-    virtual Duration plannedEffort(QDate , long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return Duration::zeroDuration; }
+    virtual Duration plannedEffort(QDate , long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const { Q_UNUSED(id); return Duration::zeroDuration; }
     /// Returns the total planned effort for @p resource on this task (or subtasks) on date
-    virtual Duration plannedEffort( const Resource *resource, QDate date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
+    virtual Duration plannedEffort(const Resource *resource, QDate date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const;
     /// Returns the planned effort up to and including date
-    virtual Duration plannedEffortTo(QDate , long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return Duration::zeroDuration; }
+    virtual Duration plannedEffortTo(QDate , long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const { Q_UNUSED(id); return Duration::zeroDuration; }
     /// Returns the planned effort for @p resource up to and including date
-    virtual Duration plannedEffortTo( const Resource *resource, QDate date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
+    virtual Duration plannedEffortTo(const Resource *resource, QDate date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const;
     
     /// Returns the total actual effort for this task (or subtasks) 
     virtual Duration actualEffort() const { return Duration::zeroDuration; }
     /// Returns the total actual effort for this task (or subtasks) on date
-    virtual Duration actualEffort(QDate /*date*/ ) const { return Duration::zeroDuration; }
+    virtual Duration actualEffort(QDate /*date*/) const { return Duration::zeroDuration; }
     /// Returns the total actual effort for this task (or subtasks) up to and including date
-    virtual Duration actualEffortTo(QDate /*date*/ ) const { return Duration::zeroDuration; }
-    virtual EffortCostMap actualEffortCostPrDay(QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const=0;
+    virtual Duration actualEffortTo(QDate /*date*/) const { return Duration::zeroDuration; }
+    virtual EffortCostMap actualEffortCostPrDay(QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const=0;
     /// Returns the actual effort and cost pr day used by @p resource
-    virtual EffortCostMap actualEffortCostPrDay(const Resource *resource, QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const=0;
+    virtual EffortCostMap actualEffortCostPrDay(const Resource *resource, QDate start, QDate end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const=0;
     
     /**
      * Planned cost is the sum total of all resources and other costs
      * planned for this node.
      */
-    virtual EffortCost plannedCost( long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
+    virtual EffortCost plannedCost(long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const;
     
     /**
      * Planned cost from start of activity up to and including date
      * is the sum of all resource costs and other costs planned for this node.
      */
-    virtual double plannedCostTo(QDate /*date*/, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return 0; }
+    virtual double plannedCostTo(QDate /*date*/, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All) const { Q_UNUSED(id); return 0; }
     /// Actual cost up to and including date
-    virtual EffortCost actualCostTo( long int /*id*/, QDate /*date*/) const { return EffortCost(); }
+    virtual EffortCost actualCostTo(long int /*id*/, QDate /*date*/) const { return EffortCost(); }
     
     /// Returns the effort planned to be used to reach the actual percent finished
-    virtual Duration budgetedWorkPerformed( QDate , long = CURRENTSCHEDULE ) const = 0;
+    virtual Duration budgetedWorkPerformed(QDate , long = CURRENTSCHEDULE) const = 0;
     /// Returns the cost planned to be used to reach the actual percent finished
-    virtual double budgetedCostPerformed( QDate , long = CURRENTSCHEDULE ) const { return 0.0; };
+    virtual double budgetedCostPerformed(QDate , long = CURRENTSCHEDULE) const { return 0.0; };
 
     /// Return map of Budgeted Cost of Work Scheduled pr day
-    virtual EffortCostMap bcwsPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All );
+    virtual EffortCostMap bcwsPrDay(long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All);
     /// Return map of Budgeted Cost of Work Scheduled pr day
-    virtual EffortCostMap bcwsPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All ) const;
+    virtual EffortCostMap bcwsPrDay(long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All) const;
     /// Budgeted Cost of Work Scheduled
-    virtual double bcws( QDate /*date*/, long id = CURRENTSCHEDULE ) const { Q_UNUSED(id); return 0.0; }
+    virtual double bcws(QDate /*date*/, long id = CURRENTSCHEDULE) const { Q_UNUSED(id); return 0.0; }
 
     /// Return map of Budgeted Cost of Work Scheduled pr day (also includes bcws pr day)
-    virtual EffortCostMap bcwpPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All );
+    virtual EffortCostMap bcwpPrDay(long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All);
     /// Return map of Budgeted Cost of Work Scheduled pr day (also includes bcws pr day)
-    virtual EffortCostMap bcwpPrDay( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All ) const;
+    virtual EffortCostMap bcwpPrDay(long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All) const;
     /// Budgeted Cost of Work Performed
-    virtual double bcwp( long id ) const { Q_UNUSED(id); return 0.0; }
-    /// Budgeted Cost of Work Performed ( up to @p date )
-    virtual double bcwp( QDate /*date*/, long id = CURRENTSCHEDULE ) const { Q_UNUSED(id); return 0.0; }
+    virtual double bcwp(long id) const { Q_UNUSED(id); return 0.0; }
+    /// Budgeted Cost of Work Performed (up to @p date)
+    virtual double bcwp(QDate /*date*/, long id = CURRENTSCHEDULE) const { Q_UNUSED(id); return 0.0; }
 
     /// Return a map of Actual effort and Cost of Work Performed
-    virtual EffortCostMap acwp( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All );
+    virtual EffortCostMap acwp(long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All);
     /// Return a map of Actual effort and Cost of Work Performed
-    virtual EffortCostMap acwp( long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All ) const;
+    virtual EffortCostMap acwp(long id = CURRENTSCHEDULE, EffortCostCalculationType type = ECCT_All) const;
     /// Return Actual effort and Cost of Work Performed upto @date
-    virtual EffortCost acwp( QDate date, long id = CURRENTSCHEDULE ) const;
+    virtual EffortCost acwp(QDate date, long id = CURRENTSCHEDULE) const;
 
     /// Effort based performance index
-    virtual double effortPerformanceIndex(QDate /*date*/, long /*id*/ = CURRENTSCHEDULE ) const { return 0.0; }
+    virtual double effortPerformanceIndex(QDate /*date*/, long /*id*/ = CURRENTSCHEDULE) const { return 0.0; }
     /// Schedule performance index
-    virtual double schedulePerformanceIndex(QDate /*date*/, long /*id*/ = CURRENTSCHEDULE ) const { return 0.0; }
+    virtual double schedulePerformanceIndex(QDate /*date*/, long /*id*/ = CURRENTSCHEDULE) const { return 0.0; }
     /// Cost performance index
-    virtual double costPerformanceIndex(  long int /*id*/, QDate /*date*/, bool * /*error=0*/ ) const { return 0.0; }
+    virtual double costPerformanceIndex(long int /*id*/, QDate /*date*/, bool * /*error=0*/) const { return 0.0; }
     
     virtual void initiateCalculationLists(MainSchedule &sch) = 0;
     virtual DateTime calculateForward(int /*use*/) = 0;
@@ -389,18 +408,18 @@ public:
     virtual void adjustSummarytask() = 0;
 
     /// Returns the (previously) calculated duration
-    Duration duration( long id = CURRENTSCHEDULE ) const;
+    Duration duration(long id = CURRENTSCHEDULE) const;
     
     /**
      * The variance is calculated based on
      * the optimistic/pessimistic ratio specified for the estimate.
      */
-    double variance( long id = CURRENTSCHEDULE, Duration::Unit unit = Duration::Unit_ms ) const;
+    double variance(long id = CURRENTSCHEDULE, Duration::Unit unit = Duration::Unit_ms) const;
     /**
      * The standard deviation is calculated based on 
      * the optimistic/pessimistic ratio specified for the estimate.
      */
-    double deviation( long id = CURRENTSCHEDULE, Duration::Unit unit = Duration::Unit_ms ) const;
+    double deviation(long id = CURRENTSCHEDULE, Duration::Unit unit = Duration::Unit_ms) const;
     
     Node *siblingBefore();
     Node *childBefore(Node *node);
@@ -410,19 +429,19 @@ public:
     bool moveChildDown(Node *node);
     
     /// Check if this node can be linked to node
-    bool legalToLink( const Node *node ) const;
+    bool legalToLink(const Node *node) const;
     /// Check if node par can be linked to node child. (Reimplement)
-    virtual bool legalToLink( const Node *, const Node *) const { return false; }
+    virtual bool legalToLink(const Node *, const Node *) const { return false; }
 
     /// Save appointments for schedule with id
     virtual void saveAppointments(QDomElement &element, long id) const;
     ///Return the list of appointments for schedule with id.
-    QList<Appointment*> appointments( long id = CURRENTSCHEDULE );
+    QList<Appointment*> appointments(long id = CURRENTSCHEDULE);
     /// Adds appointment to this node only (not to resource)
     virtual bool addAppointment(Appointment *appointment, Schedule &main);
     
     /// Return list of all resources with appointments to this task for schedule with @p id.
-    QList<Resource*> assignedResources( long id ) const;
+    QList<Resource*> assignedResources(long id) const;
     
     /// Find the node with my id
     virtual Node *findNode() const { return findNode(m_id); }
@@ -440,26 +459,26 @@ public:
      * the calendar of allocated resources. Normally this is the same
      * as @ref startTime(), but may differ if timing constraints are set.
      */
-    virtual DateTime workStartTime( long id = CURRENTSCHEDULE ) const;
-    void setWorkStartTime(const DateTime &dt,  long id = CURRENTSCHEDULE );
+    virtual DateTime workStartTime(long id = CURRENTSCHEDULE) const;
+    void setWorkStartTime(const DateTime &dt,  long id = CURRENTSCHEDULE);
     
     /**
      * This is when work can finish on this node in accordance with 
      * the calendar of allocated resources. Normally this is the same
      * as @ref endTime(), but may differ if timing constraints are set.
      */
-    virtual DateTime workEndTime( long id = CURRENTSCHEDULE ) const;
-    void setWorkEndTime(const DateTime &dt,  long id = CURRENTSCHEDULE );
+    virtual DateTime workEndTime(long id = CURRENTSCHEDULE) const;
+    void setWorkEndTime(const DateTime &dt,  long id = CURRENTSCHEDULE);
     
     /// Returns true if this node is critical
-    virtual bool isCritical( long id = CURRENTSCHEDULE ) const { Q_UNUSED(id); return false; }
+    virtual bool isCritical(long id = CURRENTSCHEDULE) const { Q_UNUSED(id); return false; }
     /// Returns true if this node is in a critical path
-    virtual bool inCriticalPath( long id = CURRENTSCHEDULE ) const;
+    virtual bool inCriticalPath(long id = CURRENTSCHEDULE) const;
     
     /// Returns the level this node is in the hierarchy. Top node is level 0.
     virtual int level() const;
     /// Generate WBS Code
-    virtual QString generateWBSCode( QList<int> &indexes, bool sortable = false ) const;
+    virtual QString generateWBSCode(QList<int> &indexes, bool sortable = false) const;
     /// Returns the Work Breakdown Structure Code
     QString wbsCode(bool sortable = false) const;
     
@@ -478,19 +497,19 @@ public:
     Account *runningAccount() const { return m_runningAccount; }
     void setRunningAccount(Account *acc);
 
-    bool isBaselined( long int id = BASELINESCHEDULE ) const;
+    bool isBaselined(long int id = BASELINESCHEDULE) const;
     /**
      * Return schedule with @p id
      * If @p id == CURRENTSCHEDULE, return m_currentSchedule
      * Return 0 if schedule with @p id doesn't exist.
      */
-    Schedule *schedule( long id = CURRENTSCHEDULE ) const;
+    Schedule *schedule(long id = CURRENTSCHEDULE) const;
     /// Return current schedule
     Schedule *currentSchedule() const { return m_currentSchedule; }
     /// Set current schedule to schedule with identity @p id, for me and my children
     virtual void setCurrentSchedule(long id);
     /// Return true if this node has a valid schedule with identity == @p id
-    bool isScheduled( long id = CURRENTSCHEDULE ) const;
+    bool isScheduled(long id = CURRENTSCHEDULE) const;
     /// Return the list of schedules for this node
     QHash<long, Schedule*> &schedules() { return m_schedules; }
     /// Find schedule matching name and type. Does not return deleted schedule.
@@ -513,23 +532,26 @@ public:
     
     /// Set deleted = onoff for schedule with id
     void setScheduleDeleted(long id, bool onoff);
-    /// Set parent schedule recursivly
+    /// Set parent schedule recursively
     virtual void setParentSchedule(Schedule *sch);
     
     const ResourceRequestCollection &requests() const { return m_requests; }
     ResourceRequestCollection &requests() { return m_requests; }
     
-    virtual uint state( long ) const { return State_None; }
+    virtual uint state(long) const { return State_None; }
     
     const Documents &documents() const { return m_documents; }
     Documents &documents() { return m_documents; }
 
-    virtual void emitDocumentAdded( Node *node, Document *doc, int idx );
-    virtual void emitDocumentRemoved( Node *node, Document *doc, int idx );
-    virtual void emitDocumentChanged( Node *node, Document *doc, int idx );
+    virtual void emitDocumentAdded(Node *node, Document *doc, int idx);
+    virtual void emitDocumentRemoved(Node *node, Document *doc, int idx);
+    virtual void emitDocumentChanged(Node *node, Document *doc, int idx);
     
     void blockChanged(bool on = true);
 
+    /// @return priority
+    int priority() const;
+
 public:
     // These shouldn't be available to other than those who inherits
     /// Calculate the critical path
@@ -564,53 +586,54 @@ public:
      * earlyStart() returns earliest time this node can start
      * given the constraints of the network.
      */
-    DateTime earlyStart( long id = CURRENTSCHEDULE ) const;
+    DateTime earlyStart(long id = CURRENTSCHEDULE) const;
     /**
      * setEarlyStart() sets earliest time this node can start
      */
-    void setEarlyStart(const DateTime &dt, long id = CURRENTSCHEDULE );
+    void setEarlyStart(const DateTime &dt, long id = CURRENTSCHEDULE);
     /**
      * lateStart() returns latest time this node can start
      * given the constraints of the network.
      */
-    DateTime lateStart( long id = CURRENTSCHEDULE ) const;
+    DateTime lateStart(long id = CURRENTSCHEDULE) const;
     /**
      * setLateStart() sets the earliest time this node can start
      */
-    void setLateStart(const DateTime &dt, long id = CURRENTSCHEDULE );
+    void setLateStart(const DateTime &dt, long id = CURRENTSCHEDULE);
     /**
      * earlyFinish() returns earliest time this node can finish
      * given the constraints of the network.
      */
-    DateTime earlyFinish( long id = CURRENTSCHEDULE ) const;
+    DateTime earlyFinish(long id = CURRENTSCHEDULE) const;
     /**
      * setEarlyFinish() sets earliest time this node can finish
      */
-    void setEarlyFinish(const DateTime &dt, long id = CURRENTSCHEDULE );
+    void setEarlyFinish(const DateTime &dt, long id = CURRENTSCHEDULE);
     /**
      * lateFinish() returns latest time this node can finish
      * given the constraints of the network.
      */
-    DateTime lateFinish( long id = CURRENTSCHEDULE ) const;
+    DateTime lateFinish(long id = CURRENTSCHEDULE) const;
     /**
      * setLateFinish() sets latest time this node can finish
      */
-    void setLateFinish(const DateTime &dt, long id = CURRENTSCHEDULE );
+    void setLateFinish(const DateTime &dt, long id = CURRENTSCHEDULE);
     
     /// Adds appointment to both this node and resource
     virtual void addAppointment(ResourceSchedule *resource, const DateTime &start, const DateTime &end, double load=100);
     
     virtual void clearProxyRelations() {}
-    virtual void addParentProxyRelations( const QList<Relation*> & ) {}
-    virtual void addChildProxyRelations( const QList<Relation*> & ) {}
+    virtual void addParentProxyRelations(const QList<Relation*> &) {}
+    virtual void addChildProxyRelations(const QList<Relation*> &) {}
     virtual void addParentProxyRelation(Node *, const Relation *) {}
     virtual void addChildProxyRelation(Node *, const Relation *) {}
     
-    virtual void changed( int property = -1 ) { changed( this, property ); }
+    virtual void changed(int property = -1) { changed(this, property); }
     Duration getmDurationForward(){ return this->m_durationForward;}
 
 public Q_SLOTS:
-    void slotStandardWorktimeChanged( StandardWorktime* );
+    void slotStandardWorktimeChanged(KPlato::StandardWorktime*);
+    void setPriority(int priority);
 
 protected:
     friend class KPlatoXmlLoaderBase;
@@ -623,7 +646,7 @@ protected:
 
     // NOTE: Cannot use setCurrentSchedule() due to overload/casting problems
     void setCurrentSchedulePtr(Schedule *schedule) { m_currentSchedule = schedule; }
-    virtual void changed(Node *node, int property = -1 );
+    virtual void changed(Node *node, int property = -1);
     
     QList<Node*> m_nodes;
     QList<Relation*> m_dependChildNodes;
@@ -674,6 +697,8 @@ protected:
     
     ResourceRequestCollection m_requests;
 
+    int m_priority;
+
 private:
     void init();
     bool m_blockChanged;
@@ -687,10 +712,10 @@ private:
   * With statistical calculations using the PERT distribution, one can arrive at a more 
   * realistic estimate than when using the expected value alone.
   */
-class KPLATOKERNEL_EXPORT Estimate {
+class PLANKERNEL_EXPORT Estimate {
 public:
     /// Constructor
-    explicit Estimate( Node *parent = 0 );
+    explicit Estimate(Node *parent = 0);
     /// Copy constructor.
     Estimate (const Estimate &estimate, Node *parent = 0);
     /// Destructor
@@ -700,7 +725,7 @@ public:
     void clear();
     
     /// Copy values from @p estimate
-    Estimate &operator=( const Estimate &estimate );
+    Estimate &operator=(const Estimate &estimate);
     
     /// Type defines the types of estimates
     enum Type {
@@ -710,7 +735,7 @@ public:
     /// Return the node that owns this Estimate
     Node *parentNode() const { return m_parent; }
     /// Set the node that owns this Estimate
-    void setParentNode( Node* parent ) { m_parent = parent; }
+    void setParentNode(Node* parent) { m_parent = parent; }
     
     /// Return estimate Type
     Type type() const { return m_type; }
@@ -719,23 +744,23 @@ public:
     /// Set estimate type to type represented by the string @p type
     void setType(const QString& type);
     /// Return estimate type as a string. If @p trans is true, it's translated
-    QString typeToString( bool trans=false ) const;
+    QString typeToString(bool trans=false) const;
     /// Return estimate type @p typ as a string. If @p trans is true, it's translated
-    static QString typeToString( Estimate::Type typ, bool trans=false );
+    static QString typeToString(Estimate::Type typ, bool trans=false);
     /// Return a stringlist of all estimate types. Translated if @p trans = true.
-    static QStringList typeToStringList( bool trans=false );
+    static QStringList typeToStringList(bool trans=false);
     
     /// Return the calendar used when Type is Duration
     Calendar *calendar() const { return m_calendar; }
     /// Set the calendar to be used when Type is Duration
-    void setCalendar( Calendar *calendar );
+    void setCalendar(Calendar *calendar);
     
     enum Risktype { Risk_None, Risk_Low, Risk_High };
     Risktype risktype() const { return m_risktype; }
     void setRisktype(Risktype type);
     void setRisktype(const QString& type);
-    QString risktypeToString( bool trans=false ) const;
-    static QStringList risktypeToStringList( bool trans=false );
+    QString risktypeToString(bool trans=false) const;
+    static QStringList risktypeToStringList(bool trans=false);
 
     /// Use defines which value to access
     enum Use { Use_Expected=0, Use_Optimistic=1, Use_Pessimistic=2 };
@@ -754,7 +779,7 @@ public:
     /// The unit in which the estimates were entered.
     Duration::Unit unit() const { return m_unit; }
     /// Set display unit.
-    void setUnit( Duration::Unit unit );
+    void setUnit(Duration::Unit unit);
     
     /// Return the expected estimate (normally entered by user)
     double expectedEstimate() const { return m_expectedEstimate; }
@@ -763,11 +788,11 @@ public:
     /// Return the pessimistic estimate (normally entered by user)
     double pessimisticEstimate() const { return m_pessimisticEstimate; }
     /// Set the expected estimate
-    void setExpectedEstimate( double value );
+    void setExpectedEstimate(double value);
     /// Set the optimistic estimate
-    void setOptimisticEstimate( double value );
+    void setOptimisticEstimate(double value);
     /// Set the pessimistic estimate
-    void setPessimisticEstimate( double value );
+    void setPessimisticEstimate(double value);
 
     /**
      * Set the optimistic estimate as a deviation from "expected" in percent
@@ -799,7 +824,7 @@ public:
      * The variance is calculated based on
      * the optimistic/pessimistic estimates, scaled to @p unit
      */
-    double variance( Duration::Unit unit ) const;
+    double variance(Duration::Unit unit) const;
     /**
      * The standard deviation is calculated based on 
      * the optimistic/pessimistic estimates, scaled to current unit.
@@ -809,7 +834,7 @@ public:
      * The standard deviation is calculated based on 
      * the optimistic/pessimistic estimates, scaled to @p unit
      */
-    double deviation( Duration::Unit unit ) const;
+    double deviation(Duration::Unit unit) const;
     
     /// Returns the expected duration. Calculated based on the estimates expected, optimistic and pessimistic
     Duration pertExpected() const;
@@ -819,9 +844,9 @@ public:
     Duration pertPessimistic() const;
     
     /// Convert the duration @p value (in milliseconds) to a value in @p unit, using the scaling factors in @p scales
-    static double scale( const Duration &value, Duration::Unit unit, const QList<qint64> &scales );
+    static double scale(const Duration &value, Duration::Unit unit, const QList<qint64> &scales);
     /// Convert the duration @p value (in @p unit) to a value in milliseconds (base unit), using the scaling factors in @p scales
-    static Duration scale( double value, Duration::Unit unit, const QList<qint64> &scales );
+    static Duration scale(double value, Duration::Unit unit, const QList<qint64> &scales);
 
     /// Return a list of default scales scaling factors
     static QList<qint64> defaultScales();
@@ -841,9 +866,9 @@ protected:
     /// Set (calculate) cached value
     void setPessimisticValue();
     /// Notify parent of changes
-    void changed() { if ( m_parent ) m_parent->changed(); }
+    void changed(int property) { if (m_parent) m_parent->changed(property); }
     /// Copy @p estimate, parentNode is not copied
-    void copy( const Estimate &estimate );
+    void copy(const Estimate &estimate);
     
 private:
     friend class Node;
