@@ -329,7 +329,7 @@ void PerformanceTester::acwpPrDayTask()
     
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 10);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -343,7 +343,7 @@ void PerformanceTester::acwpPrDayTask()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 20);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 6, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 6, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -355,7 +355,7 @@ void PerformanceTester::acwpPrDayTask()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 30);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -367,7 +367,7 @@ void PerformanceTester::acwpPrDayTask()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 50);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -379,7 +379,7 @@ void PerformanceTester::acwpPrDayTask()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 80);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 12, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 12, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -707,7 +707,7 @@ void PerformanceTester::acwpPrDayTaskMaterial()
     
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 10);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -721,7 +721,7 @@ void PerformanceTester::acwpPrDayTaskMaterial()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 20);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 6, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 6, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -733,7 +733,7 @@ void PerformanceTester::acwpPrDayTaskMaterial()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 30);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -746,7 +746,7 @@ void PerformanceTester::acwpPrDayTaskMaterial()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 50);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -758,7 +758,7 @@ void PerformanceTester::acwpPrDayTaskMaterial()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 80);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 12, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 12, 0)));
     cmd->execute(); delete cmd;
     ecb = t1->bcwpPrDay();
     eca = t1->acwp();
@@ -1039,7 +1039,7 @@ void PerformanceTester::acwpPrDayProject()
     
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 10);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = p1->bcwpPrDay();
     eca = p1->acwp();
@@ -1052,7 +1052,7 @@ void PerformanceTester::acwpPrDayProject()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 20);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 6, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 6, 0)));
     cmd->execute(); delete cmd;
     ecb = p1->bcwpPrDay();
     eca = p1->acwp();
@@ -1064,7 +1064,7 @@ void PerformanceTester::acwpPrDayProject()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 30);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = p1->bcwpPrDay();
     eca = p1->acwp();
@@ -1076,7 +1076,7 @@ void PerformanceTester::acwpPrDayProject()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 50);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 8, 0)));
     cmd->execute(); delete cmd;
     ecb = p1->bcwpPrDay();
     eca = p1->acwp();
@@ -1088,7 +1088,7 @@ void PerformanceTester::acwpPrDayProject()
     d = d.addDays(1);
     cmd = new ModifyCompletionPercentFinishedCmd(t1->completion(), d, 80);
     cmd->execute(); delete cmd;
-    cmd = new AddCompletionActualEffortCmd(*ue, d, Completion::UsedEffort::ActualEffort(Duration(0, 12, 0)));
+    cmd = new AddCompletionActualEffortCmd(t1, r1, d, Completion::UsedEffort::ActualEffort(Duration(0, 12, 0)));
     cmd->execute(); delete cmd;
     ecb = p1->bcwpPrDay();
     eca = p1->acwp();
